clear_inventory_changes

Function clear_inventory_changes 

pub fn clear_inventory_changes(pid: u16)
Clear the last recorded inventory changes for a player.

This is used to initialize the sending of new PlayerInventory packets.

pid The player ID whose inventory changes should be used.

Returns void