clear_journal_changes

Function clear_journal_changes 

pub fn clear_journal_changes(pid: u16)
Clear the last recorded journal changes for a player.

This is used to initialize the sending of new PlayerJournal packets.

pid The player ID whose journal changes should be used.

Returns void