clear_quick_key_changes

Function clear_quick_key_changes 

pub fn clear_quick_key_changes(pid: u16)
Clear the last recorded quick key changes for a player.

This is used to initialize the sending of new PlayerQuickKeys packets.

pid The player ID whose quick key changes should be used.

Returns void