get_actor_killer_name

Function get_actor_killer_name 

pub fn get_actor_killer_name(index: u16) -> String
Get the name of the actor killer of the actor at a certain index in the read actor list.

index The index of the actor.

Returns the name of the killer.