get_actor_killer_ref_id

Function get_actor_killer_ref_id 

pub fn get_actor_killer_ref_id(index: u16) -> String
Get the refId of the actor killer of the actor at a certain index in the read actor list.

index The index of the actor.

Returns the refId of the killer.