get_actor_killer_ref_num

Function get_actor_killer_ref_num 

pub fn get_actor_killer_ref_num(index: u16) -> u16
Get the refNum of the actor killer of the actor at a certain index in the read actor list.

index The index of the actor.

Returns the refNum of the killer.