get_data_file_enforcement_state

Function get_data_file_enforcement_state 

pub fn get_data_file_enforcement_state() -> bool
Get the data file enforcement state of the server.

If true, clients are required to use the same data files as set for the server.

Returns the enforcement state.