get_record_flags

Function get_record_flags 

pub fn get_record_flags(index: u16) -> i16
Get the flags of the record at a certain index in the read worldstate’s
dynamic records of the current type.

index The index of the record.

Returns the flags of the spell as an integer.