is_class_default

Function is_class_default 

pub fn is_class_default(pid: u16) -> i16
Check whether the player is using a default class instead of a custom one.

pid The player ID.

Returns whether the player is using a default class.