send_object_delete

Function send_object_delete 

pub fn send_object_delete(
    send_to_other_players: bool,
    skip_attached_player: bool,
)
Send an ObjectDelete packet.

broadcast Whether this packet should be sent only to the player for whom the current
object list was initialized or to everyone on the server.

Returns void